@@ -39,8 +39,8 @@ subtype VCF_Chrom, as Str_No_Whitespace;
 
 subtype VCF_Ref,
 	as      Str,
-	where   { /^-$/ || /^[CGAT]+$/i },
-	message {"VCF_Ref must be '-' (dash), or a series of 'CGAT' characters"};
+	where   { /^-$/ || /^[.CGAT]+$/i },
+	message {"VCF_Ref must be '-' (dash), or a series of '.CGAT' characters"};
 
 subtype VCF_Ref_Full,
 	as      Str,
